qgis_session_info reports the version of QGIS and
installed third-party providers (so far GRASS 6, GRASS 7, and SAGA).
Additionally, it figures out with which SAGA versions the QGIS installation
is compatible.
Usage
qgis_session_info(qgis_env = set_env())
Arguments
qgis_env
Environment settings containing all the paths to run the QGIS
API. For more information, refer to set_env.
Value
The function returns a list with following elements:
qgis_version: Name and version of QGIS used by RQGIS.
grass6: GRASS 6 version number. Under Linux, the function only checks if
GRASS 6 modules can be executed, therefore it simply returns TRUE instead of
a version number.
grass7: GRASS 7 version number. Under Linux, the function only checks if
GRASS 6 modules can be executed, therefore it simply returns TRUE instead of
a version number
saga: The installed SAGA version used by QGIS.
supported_saga_versions: character vector representing the SAGA
versions supported by the QGIS installation.