Learn R Programming

RQGIS (version 0.1.0)

saga_support: Find the SAGA versions QGIS supports

Description

saga_support calls via the QGIS Python API the SagaAlgorithmProvider to figure out with which SAGA versions QGIS currently is compatible.

Usage

saga_support(qgis_env = set_env())

Arguments

qgis_env
Environment settings containing all the paths to run the QGIS API. For more information, refer to set_env.

Value

The function returns a character vector representing the SAGA version numbers QGIS currently supports.

Examples

Run this code
## Not run: 
# saga_support()
# ## End(Not run)

Run the code above in your browser using DataLab