Draw a Rectangle on the QGIS Map Canvas
qgis_draw_bbox.RdInteractively prompts the user to draw a rectangle on the QGIS map canvas and returns its bounding box.
Examples
if (FALSE) { # \dontrun{
# Draw a bounding box and save the extent to a variable
my_bbox <- qgis_draw_bbox()
print(my_bbox)
} # }