Draw Points on the QGIS Map Canvas
qgis_draw_points.RdInteractively prompts the user to draw a specified number of points
on the QGIS map canvas and returns them as an sfc object.
Examples
if (FALSE) { # \dontrun{
# Draw a single point
pt <- qgis_draw_points()
# Draw 3 points
pts <- qgis_draw_points(n = 3)
print(pts)
} # }