Learn R Programming

RQGIS (version 0.1.0)

qgis_session_info: QGIS session info

Description

qgis_session_info reports the version of QGIS and installed third-party providers (so far GRASS 6, GRASS 7, and SAGA). Additionally, it figures out with which SAGA versions the QGIS installation is compatible.

Usage

qgis_session_info(qgis_env = set_env())

Arguments

qgis_env
Environment settings containing all the paths to run the QGIS API. For more information, refer to set_env.

Value

The function returns a list with following elements:
  1. qgis_version: Name and version of QGIS used by RQGIS.
  2. grass6: GRASS 6 version number. Under Linux, the function only checks if GRASS 6 modules can be executed, therefore it simply returns TRUE instead of a version number.
  3. grass7: GRASS 7 version number. Under Linux, the function only checks if GRASS 6 modules can be executed, therefore it simply returns TRUE instead of a version number
  4. saga: The installed SAGA version used by QGIS.
  5. supported_saga_versions: character vector representing the SAGA versions supported by the QGIS installation.

Examples

Run this code
## Not run: 
# qgis_session_info()
# ## End(Not run)

Run the code above in your browser using DataLab